{% extends 'flask_user/public_base.html' %}

{% block content %}
{% from "base_templates/form_macros.html" import render_field, render_submit_field %}

<h1>Create package</h1>

<form action="" method="POST" role="form">
  {{ form.hidden_tag() }}
  <div class="form-group">
    {{ render_field(form.name) }}
  </div>
  <div class="form-actions">
    {{ render_submit_field(form.submit, data={'disable-button': 0}) }}
  </div>

</form>

{% endblock %}
