{% extends 'base_templates/flask_wide_base.html' %}

{% block content %}
<h1>Test Web Sockets</h1>
<div class="row"><div class="col-md-12" id="daCorrespondence"></div></div>
<div class="row"><div class="col-md-12"><textarea id="daMessage"></textarea></div></div>
<div class="row"><div class="col-md-12"><a tabindex="0" class="btn" id="daSend">Send</a></div></div>
<div class="row"><div class="col-md-12"><p id="daPushResult"></p></div></div>
{% endblock %}
