{%- set userclass = True %}
{%- extends "base_templates/base.html" %}
{%- block main %}
      <div class="row">
        <div class="offset-lg-3 col-lg-6 offset-md-2 col-md-8 offset-sm-1 col-sm-10">
          {%- if version_warning and current_user.has_roles(['admin', 'developer']) %}
          <div class="alert alert-danger">
            {{ version_warning }}
          </div>
          {%- endif %}
          {% block content %}{% endblock %}
        </div>
      </div>
{%- endblock %}
