{% extends 'flask_user/emails/base_message.html' %}

{% block message %}

<p>{{ word('Thank you for registering with') }} {{ app_name }}.</p>

{% if user_manager.enable_confirm_email %}
<p>{{ word('You will need to confirm your email next.') }}</p>

<p>{{ word('If you initiated this registration, please click on the link below:') }}<br/>
&nbsp;&nbsp;&nbsp;&nbsp;<a href="{{ confirm_email_link }}">{{ word('Confirm your email') }}</a>.</p>

<p>{{ word('If you did not initiate this registration, you may safely ignore this email.') }}</p>
{% endif %}

{% endblock %}
